################################################################################

#  Taller GBIF.ES: Manejo, visualizacin y anlisis de datos en ecologa con R
# Code by: Julia Chacn Labella
# Date: Octubre 2019
# email: chacon.julia@inia.es
# Tema 6: Edicin de figuras con ggplot2 (PARTE 2)

#############################################################################
# Diagramas de cajas (boxplots) e histogramas. 
# Otros recursos para mejorar mis grficos con ggplot2.
############################################################################

miplot

###################
#      BOXPLOTS
###################

# diagrama de cajas: se componen de CAJAS (box) y "BIGOTES" (whiskers)
# nos permite ver la distribucin de una variable continua de forma compacta. 
# nos permite visualizar la mediana e esa distribucin, los valores atipicos (ouliers)
# los cuartiles
# sirven para detectar valores atipicos y ver a simple vista la 
# simetra de la distribucin de los datos
# si la mediana est centrada o no, etc.

ggplot(iris, aes(Species, Sepal.Length))

ggplot(iris, aes(Species, Sepal.Length)) +
  geom_boxplot()

ggplot(iris, aes(Species, Sepal.Length))+
  geom_boxplot(fill="red", col="black")

ggplot(iris, aes(Species, Sepal.Length)) +
    geom_boxplot(fill = "white", colour = "#3366FF")

ggplot(iris, aes(Species, Sepal.Length)) +
  geom_boxplot(fill="white", col="#3366FF", notch=TRUE)
  
ggplot(iris, aes(Species, Sepal.Length, col=Species)) +
  geom_boxplot()

ggplot(iris, aes(Species, Sepal.Length)) +
  geom_boxplot(aes(col=Species))

ggplot(iris, aes(Species, Sepal.Length)) +
  geom_boxplot(aes(fill=Species))

ggplot(iris, aes(Species, Sepal.Length, fill=Species)) +
  geom_boxplot()

# recordar que ggplot hace capas, y superpone unos elementos a otros
# es decir, el orden en que damos las cosas, importa. Mirad este ejemplo:

ggplot(iris, aes(Species, Sepal.Length)) +
  geom_boxplot(fill="red", col="black", notch=TRUE)+
  geom_point()

ggplot(iris, aes(Species, Sepal.Length)) +
  geom_point()+  
  geom_boxplot(fill="red", col="black", notch=TRUE)

###################
# HISTOGRAMAS
###################

ggplot(iris, aes(Sepal.Length)) +
  geom_histogram(binwidth=0.3)
  
ggplot(iris, aes(Sepal.Length, fill=Species)) +
  geom_histogram(binwidth=0.2)

ggplot(iris, aes(Sepal.Length, col=Species)) +
  geom_freqpoly(binwidth=0.2) # generalmente se visualiza mejor con frecuencias

data(diamonds)
## mismo ejemplo con el dataset diamonds
miplot2 <- ggplot(diamonds, aes(price, fill = cut)) +
  geom_histogram(binwidth = 500)

ggplot(diamonds, aes(price, colour = cut)) +
  geom_freqpoly(binwidth = 500)

############################################################################
# Otros aspectos de ggplot interesantes que puedes modificar
############################################################################

##########
## la funcin theme() los "temas" te permiten definir elementos como 
# el color del fondo, tamao de los ejes, titulo, etc.
##########

miplot
miplot2

# podemos hacer cambios por ejemplo en el color de fondo
miplot + theme(panel.grid = element_blank()) # las lineas ya no estn

# si exploramos theme() vemos que hay muchisimso componentes que nos permiten 
#controlar los elementos de un plot

?theme #muchisismos argumentos para controlar los elementos del plot

miplot + theme(panel.grid = element_blank(),
               panel.background = element_rect(fill="white"),
               axis.line.y=element_line(colour ="black", size=0.5),
               axis.line.x=element_line(colour ="black", size=0.5)) 

miplot + theme(panel.grid = element_blank(),
               panel.background = element_rect(fill="white"),
               panel.border=element_rect(colour="black", fill=NA, size=0.5)) 

#hay muchos "temas" definidos por defecto y que puedo utilizar
miplot + theme_bw()
miplot + theme_dark()
miplot + theme_classic()

#  puedo definir mi propio tema
miplot + mitema # mitema debe estar guardado como un objeto creado con theme()

mitema <- theme(panel.grid = element_blank(),
                panel.background = element_rect(fill="white"),
                axis.line.y=element_line(colour ="black", size=0.5),
                axis.line.x=element_line(colour ="black", size=0.5),
                axis.title = element_text(size=20)) 
miplot + mitema

# una vez definido tu tema, lo puedes guardar y usarlo siempre
# de forma que tus figuras seran homogeneas en tus documentos

##################
## ejes y titulo  
##################

miplot + theme_bw() +
  labs(x="", y ="Anchura de los sepalos (mm)") +
  ggtitle("Anchura de los sepalos de las especies de Iris") +
  theme(plot.title = element_text(hjust=0.5, size=15)) # TITULO

mitema <- theme(panel.grid = element_blank(),
          panel.background = element_rect(fill="white"),
          axis.line.y=element_line(colour ="black", size=0.5),
          axis.line.x=element_line(colour ="black", size=0.5),
          axis.title = element_text(size=15),
          plot.title = element_text(hjust=0.5, size =15)) 

miplot+ mitema + labs(x="", y ="Anchura de los sepalos (mm)") +
  ggtitle("Anchura de los sepalos de las especies de Iris") +
  theme(plot.title = element_text(hjust=0.5, size=15))

#hjust=0.5 ajusta el titulo a la mitad del grfico

###################
# SALVAR EL PLOT
###################
# ggsave()# salva el ultimo plot que hayas hecho 
# recuerda tener tu directorio de trabajo bien asignado primero
ggsave("Grafico 1.pdf")
ggsave("Grafico 2.pdf", width = 8, height = 5, unit ="in")











