################################################################################

#  Taller GBIF.ES: Manejo, visualizacin y anlisis de datos en ecologa con R
# Code by: Julia Chacn Labella
# Date: Octubre 2019
# email: chacon.julia@inia.es
# Tema 6: Edicin de figuras con ggplot2  (PARTE 1)

################################################################################
# Introduccin a los grficos en ggplot2 : 
# Diagramas de dispersin (scatterplots) y de barras (barplots). 
###################################

install.packages(ggplot2)
library(ggplot2)

data(iris)
head(iris)
plot(iris)
plot(iris$Sepal.Length, iris$Sepal.Width)

#  GGPLOT
# contruye los graficos aadiendo capas con el operador del +

# La funcin principal del paquete es ggplot()
# Necesita dos argumentos principales, los datos, es decir el data frame que 
# quieres dibujar (datos) y el argumento aes (aesthetic mapping)
# aes es la relacin entre una variable de tu data frame y tu plot
#  
ggplot(iris, aes(x = Sepal.Length, y = Sepal.Width))

###################
## scatterplots
##################
# si queremos que dibuje algo le tenemos que decir EL QU 
ggplot(iris, aes(x = Petal.Length, y = Sepal.Width)) +
  geom_point() # este argumento te dibuja objetos, en este caso puntos.
# siempre es geom_ALGO (puntos, lineas, barras...etc)

############################################
?geom_point # se abre el panel de ayuda de R
# bajas a aesthetics
# x,y son obligadas en aes() por eso estan en negrita en help
# el resto son opcionales, las puedes dar o no. 
#############################################
# vamos a colorear los puntos dependiendo de la especie
ggplot(iris, aes(x = Petal.Length, y = Sepal.Width, col = Species)) +
  geom_point() 

# se pone en aesthetic, como hemos visto en la ayuda
# automaticamente se dibuja una leyenda
### imaginemos que tambien queremos representar petal.width
# de manera que el tamao de los puntos dependa de petal.width
ggplot(iris, aes(x = Petal.Length, y = Sepal.Width, col = Species,
                 size = Petal.Width )) +
  geom_point()

## podemos diferenciar las especies por color y tambien por forma
ggplot(iris, aes(x = Petal.Length, y = Sepal.Width, col = Species,
                 size = Petal.Width, shape= Species)) +
  geom_point()

# Orden para dibujar:
# 1. Hacemos una grfica con ggplot
# 2. aadimos objetos geometricos (geom_ALGO)
# 3. Usamos aes para indicar de qu forma queremos que se muestren las variables

###############
## BARPLOTS
###############

ggplot(iris, aes(x = Species, y = Petal.Length)) +
  geom_bar()

# nos da un error
?geom_bar

# bar plot cuenta observaciones, sirve para histagramas, datos de frecuencias
ggplot(iris, aes(x = Species)) +
  geom_bar()

# esta figura no tiene mucho sentido

# En lugar de especies vamos a dibujar sepalwidht
ggplot(iris, aes(x = Sepal.Width)) +
  geom_bar()


ggplot(iris, aes(x = Sepal.Width)) +
  geom_bar(stat="count") # por defecto "cuenta" el numero de casos
# dibuja la distribucin de frecuencias (sale lo mismo)

# pero podria dibujar otro estadistico, como la media
ggplot(iris, aes(x=Species, y=Sepal.Width)) +
  geom_bar(stat="summary", fun.y= "mean") # qu funcin de y?

# podria dibujar otro estadistico, como la media y aadir colores
ggplot(iris, aes(Species,Sepal.Width, col=Species)) +
  geom_bar(stat="summary", fun.y= "mean") 

# como veis se refiere a los bordes. Rellenemos el interior
ggplot(iris, aes(Species,Sepal.Width, fill=Species)) +
  geom_bar(stat="summary", fun.y= "mean") 

## tambin podemos asignar un color que no guarda relacin con las variables
ggplot(iris, aes(Species,Sepal.Width)) +
  geom_bar(stat="summary", fun.y= "mean", fill="blue") 

ggplot(iris, aes(Species,Sepal.Width)) +
  geom_bar(stat="summary", fun.y= "mean", fill="#ff0002", col ="blue" ) 

## aadir los puntos que representan las observaciones individuales
ggplot(iris, aes(Species,Sepal.Width)) +
  geom_bar(stat="summary", fun.y= "mean", fill="#ff0002", col ="black" )+
  geom_point()


## aadir los puntos que representan las observaciones individuales
# Podemos modificar como se muestran los puntos
# controlar el ancho con el que se muestra
ggplot(iris, aes(Species,Sepal.Width)) +
  geom_bar(stat="summary", fun.y= "mean", fill="#ff0002", col ="black" )+
  geom_point(position=position_jitter())


ggplot(iris, aes(Species,Sepal.Width)) +
  geom_bar(stat="summary", fun.y= "mean", fill="#ff0002", col ="black" )+
  geom_point(position=position_jitter(0.2), size=1, shape=21)

# podis jugar con este parmetro
# con la forma y con el tamao
# si escribs en google, graphical parameters ggplot2 
# podis aprender ms sobre los parmetro grficos
https://www.statmethods.net/advgraphs/parameters.html

## Podemos asignar el plot a un objeto, en este caso: miplot

miplot <- ggplot(iris, aes(Species,Sepal.Width)) +
  geom_bar(stat="summary", fun.y= "mean", fill="#ff0002", col ="black" )+
  geom_point(position=position_jitter(0.2), size=2, shape=21)

miplot

